@@ -11,9 +11,12 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-import sys
 import copy
+import datetime
 import six
+import sys
+
+
 if six.PY3:
     from six.moves import http_client
     class HTTPHeaders(http_client.HTTPMessage):
@@ -27,6 +30,11 @@ if six.PY3:
     from io import IOBase as _IOBase
     file_type = _IOBase
 
+    # In python3, unquote takes a str() object, url decodes it,
+    # then takes the bytestring and decodes it to utf-8.
+    # Python2 we'll have to do this ourself (see below).
+    unquote_str = unquote
+
     def set_socket_timeout(http_response, timeout):
         """Set the timeout of the socket from an HTTPResponse.
 
@@ -52,6 +60,16 @@ else:
             for field, value in self._headers:
                 yield field
 
+    def unquote_str(value, encoding='utf-8'):
+        # In python2, unquote() gives us a string back that has the urldecoded
+        # bits, but not the unicode parts.  We need to decode this manually.
+        # unquote has special logic in which if it receives a unicode object it
+        # will decode it to latin1.  This is hard coded.  To avoid this, we'll
+        # encode the string with the passed in encoding before trying to
+        # unquote it.
+        byte_string = value.encode(encoding)
+        return unquote(byte_string).decode(encoding)
+
     def set_socket_timeout(http_response, timeout):
         """Set the timeout of the socket from an HTTPResponse.
 
@@ -108,3 +126,25 @@ def copy_kwargs(kwargs):
     else:
         copy_kwargs = copy.copy(kwargs)
     return copy_kwargs
+
+
+def total_seconds(delta):
+    """
+    Returns the total seconds in a ``datetime.timedelta``.
+
+    Python 2.6 does not have ``timedelta.total_seconds()``, so we have
+    to calculate this ourselves. On 2.7 or better, we'll take advantage of the
+    built-in method.
+
+    The math was pulled from the ``datetime`` docs
+    (http://docs.python.org/2.7/library/datetime.html#datetime.timedelta.total_seconds).
+
+    :param delta: The timedelta object
+    :type delta: ``datetime.timedelta``
+    """
+    if sys.version_info[:2] != (2, 6):
+        return delta.total_seconds()
+
+    day_in_seconds = delta.days * 24 * 3600.0
+    micro_in_seconds = delta.microseconds / 10.0**6
+    return day_in_seconds + delta.seconds + micro_in_seconds
