@@ -18,7 +18,7 @@ from botocore.exceptions import MissingParametersError
 from botocore.exceptions import UnknownParameterError
 from botocore.paginate import Paginator
 from botocore.payload import Payload, XMLPayload, JSONPayload
-from botocore import BotoCoreObject
+from botocore import BotoCoreObject, xform_name
 
 logger = logging.getLogger(__name__)
 
@@ -156,6 +156,7 @@ class Operation(BotoCoreObject):
         """
         built_params = self._get_built_params()
         missing = []
+        kwargs = self._camel_to_snake_case(kwargs)
         self._check_for_unknown_params(kwargs)
         for param in self.params:
             if param.required:
@@ -172,6 +173,15 @@ class Operation(BotoCoreObject):
                                          object_name=self)
         return built_params
 
+    def _camel_to_snake_case(self, kwargs):
+        """
+        Converts top level keys in `kwargs` from camel case to snake case
+        """
+        params = {}
+        for key, value in kwargs.items():
+            params[xform_name(key)] = value
+        return params
+
     def _check_for_unknown_params(self, kwargs):
         valid_names = [p.py_name for p in self.params]
         for key in kwargs:
